==> excel-parse-yl-1.0.3.tgz: package/index.js <==
/**
 * 安装node-xlsx插件
 */
 var path = require('path')
 var fs = require('fs')
 var xlsx = require('node-xlsx')
//  let filePath = "C:/Users/admin/Desktop/test.xlsx"
  
function getExcelData( filePath, hasTitle,keysString) {
    return new Promise( (resolve, reject ) => {
        let blob = fs.readFileSync( filePath )
         try {
            var obj = xlsx.parse(  blob  )
            let keyArr = keysString.split(",")
            var newArray = []
            let arr = obj[0].data
            if (hasTitle) {
                let titleKey = arr[0]
                for (let i = 1; i < arr.length; i++) {
                    const el = arr[i];
                    let itemObj = {}
                    for (let j = 0; j < el.length; j++) {
                        const val = el[j];
                        let keys = titleKey[j]
                        if ( keys ) {
                            itemObj[keys] = val
                        }
                        
                    }
                    newArray.push( itemObj )
                    
                }
            } else {
                for (let i = 0; i < arr.length; i++) {
                    const el = arr[i];
                    let itemObj = {}
                    for (let j = 0; j < el.length; j++) {
                        const val = el[j];
                        let keys = keyArr[j]
                        if ( keys ) {
                            itemObj[keys] = val
                        }
                        
                    }
                    newArray.push( itemObj )
                    
                }
            }
            resolve(newArray) 
         } catch (error) {
             reject( error )
         }
        
    })
    
}

==> excel-parse-yl-1.0.4.tgz: package/index.js <==
/**
 * 安装node-xlsx插件
 */
 var path = require('path')
 var fs = require('fs')
 var xlsx = require('node-xlsx')
//  let filePath = "C:/Users/admin/Desktop/test.xlsx"
  
function getExcelDataFormFilePath( filePath, hasTitle,keysString) {
    return new Promise( (resolve, reject ) => {
        let blob = fs.readFileSync( filePath )
         try {
            var obj = xlsx.parse(  blob  )
            let keyArr = keysString.split(",")
            var newArray = []
            let arr = obj[0].data
            if (hasTitle) {
                let titleKey = arr[0]
                for (let i = 1; i < arr.length; i++) {
                    const el = arr[i];
                    let itemObj = {}
                    for (let j = 0; j < el.length; j++) {
                        const val = el[j];
                        let keys = titleKey[j]
                        if ( keys ) {
                            itemObj[keys] = val
                        }
                        
                    }
                    newArray.push( itemObj )
                    
                }
            } else {
                for (let i = 0; i < arr.length; i++) {
                    const el = arr[i];
                    let itemObj = {}
                    for (let j = 0; j < el.length; j++) {
                        const val = el[j];
                        let keys = keyArr[j]
                        if ( keys ) {
                            itemObj[keys] = val
                        }
                        
                    }
                    newArray.push( itemObj )
                    
                }
            }
            resolve(newArray) 
         } catch (error) {
             reject( error )
         }
        
    })
    
}

function getExcelDataFromUploadForWeb( file, hasTitle, keysString ) {
    let fileReader = new FileReader()
    let newArray = []
    let keyArr = keysString.split(",")
      fileReader.onload = ( e ) => {
        let data = e.target.result
        let workbook = XLSX.read( data, { type:"binary" })
        var sheetNames = workbook.SheetNames; // 工作表名称集合
        var worksheet = workbook.Sheets[sheetNames[0]]; // 这里我们只读取第一张sheet
        var csv = XLSX.utils.sheet_to_csv(worksheet);
        let arr = csv.split("\n")
        if (hasTitle) {
            let titleKey = arr[0].split(",")
            for (let i = 1; i < arr.length; i++) {
                const el = arr[i];
                if ( el.length ) {
                    let itemObj = {}
                    let elArr = el.split(",")
                    for (let j = 0; j < elArr.length; j++) {
                        const val = elArr[j];
                        let keys = titleKey[j]
                        if ( keys ) {
                            itemObj[keys] = val
                        }
                    }
                    newArray.push( itemObj )
                }
                
            }
        } else {
            for (let i = 0; i < arr.length; i++) {
                const el = arr[i];
                if ( el.length ) {
                    let itemObj = {}
                    let elArr = el.split(",")
                    for (let j = 0; j < elArr.length; j++) {
                        const val = elArr[j];
                        let keys = keyArr[j]
                        if ( keys ) {
                            itemObj[keys] = val
                        }
                    }
                    newArray.push( itemObj )
                }
                
            }
        }
        return newArray
      }
      fileReader.readAsBinaryString( file )
}
